@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: texmath
-version: 0.8.5.1
-id: texmath-0.8.5.1-12fde9597135cf71aeccebd23ab95779
-key: texma_97pAXRsYKbg9Ib26hHTvj7
+version: 0.8.6.1
+id: texmath-0.8.6.1-5f9e05ceca1cc643ef8bc76de94907d1
+key: texma_70gVuLSWKMaHtCmnebC0QD
 license: GPL
 maintainer: jgm@berkeley.edu
 stability: Experimental
@@ -56,10 +56,10 @@ exposed-modules:
 hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
                 Text.TeXMath.TeX Paths_texmath
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.5.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.5.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.5.1
-hs-libraries: HStexmath-0.8.5.1-97pAXRsYKbg9Ib26hHTvj7
+import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.6.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.6.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.6.1
+hs-libraries: HStexmath-0.8.6.1-70gVuLSWKMaHtCmnebC0QD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
